% script file GitterReg.m
% regularisation of a triangular mesh
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; clear all; 

n = 20; % number of points along one boundary

discretise_circle; % triangulation from Ex. 1, Blatt 6

% now do the coordinate regularisation
[A,RHSx,RHSy] = sysmat_GitterReg(N,n,TRI,Nodes);

NodesNew.x = A\RHSx;
NodesNew.y = A\RHSy;

% add the boundary points
NodesNew.x = [NodesNew.x;bd_x];
NodesNew.y = [NodesNew.y;bd_y];


figure(1);
subplot(2,2,3);
P=trimesh(TRI,NodesNew.x,NodesNew.y);
set(P,'color','r');
hold on
axis equal;
title('Improved triangulation (slash)');

figure(2);
clf;
P=trimesh(TRI,Nodes.x,Nodes.y);
set(P,'color','k');
hold on
P=trimesh(TRI,NodesNew.x,NodesNew.y);
set(P,'color','r','linewidth',2);
axis equal

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CG method

x0 = 1*ones(size(RHSx));
y0 = 1*ones(size(RHSx));

% better  guess for iv: old coordinates
%x0 = Nodes.x(1:N-n);
%y0 = Nodes.y(1:N-n);

toler = 1e-12;
maxit = 500;

K = A'*A; % symmetrise
NodesNewCG.x = cg(K,A'*RHSx,x0,toler,maxit);
NodesNewCG.y = cg(K,A'*RHSy,y0,toler,maxit);

% add the boundary points
NodesNewCG.x = [NodesNewCG.x;bd_x];
NodesNewCG.y = [NodesNewCG.y;bd_y];


figure(1);
subplot(2,2,4);
P=trimesh(TRI,NodesNewCG.x,NodesNewCG.y);
set(P,'color','g');
hold on
axis equal;
title('Improved triangulation (CG)');

figure(4)
P=trimesh(TRI,NodesNewCG.x,NodesNewCG.y);
set(P,'color','g','linewidth',1);
axis equal

return 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CG once more, this time visualise the iterates

visualise_iterates;



