function [A,RHSx,RHSy] = sysmat_GitterReg(N,n,TRI,Nodes);
% system matrix for grid regularisation
% assume that boundary nodes follow as last
% RHSx: system for finding the x-component
% RHSy: ---"---                y ---"---
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% build the system matrix
A = sparse(N-n,N); % reserve the memory, at first include also bdry nodes
for ctr = 1:N-n; % all inner points
  % current grid point
  x_loc = Nodes.x(ctr);
  y_loc = Nodes.y(ctr);
  
 % an inner point, seek the neighbours
    
  % (1) find all triangles (triangle numbers) in which the node is present
  % (a) as the first triangle node:
  tri_loc1 = find(TRI(:,1)==ctr);
  % (b) as the second triangle node:
  tri_loc2 = find(TRI(:,2)==ctr);
  % (c) as the thirs triangle node:
  tri_loc3 = find(TRI(:,3)==ctr);
    
  % all together
  tri_loc = [tri_loc1;tri_loc2;tri_loc3];
    
  % number of neighbouring triangles:
  N_tri = length(tri_loc);
    
  % (2) pick out the nodes out of triangles:
  % these are VALUES of TRI(tri_loc);
  % (node indices)
  nodes_loc = TRI(tri_loc,:);
    
  % pass to scalar array:
  nodes_loc = reshape(nodes_loc,[3*N_tri,1]);
    
  % skip the point itself:
  nodes_loc = setdiff(nodes_loc,ctr);
  % make the story unique
  nodes_loc = unique(nodes_loc);
    
  % visualise
  if 0
    figure(100);
    clf
    TM=trimesh(TRI,Nodes.x,Nodes.y);
    set(TM,'Color',[0.7 0.7 0.7]);
    hold on
    
    plot(x_loc,y_loc,'r*');
    plot(Nodes.x(nodes_loc),Nodes.y(nodes_loc),'g*');
    axis equal
    drawnow
    %pause
  end
    
  % number of neighbours
  N_neighbours = length(nodes_loc);
    
  % fill the values in A away from the diagonal
  A(ctr,nodes_loc) = -1/N_neighbours;
  %A(ctr,ctr) = 1;    
  
end

% split A into two parts:
% A for inner nodes acting on inner nodes and
% A for outer nodes acting on inner nodes


Abdry = A(:,N-n+1:N);
A = A(:,1:N-n);
% for inner-to-inner add the main diagonal
A = A + speye(N-n,N-n);

% the rhs:
RHSx = -Abdry*Nodes.x(N-n+1:N);
RHSy = -Abdry*Nodes.y(N-n+1:N);




